Docmentation will in future be here, but there is not much there yet.

* http://futuregrid.github.com/flask_cm/


flask_cm
--------

major code


start with 

fab cm

TODO: bugs in imports after reorganization

does not work





examples
----------------------

* examples/hello - a simple hello world program with a OSX makefile to test from the same window
  * bootstrap documentation: http://twitter.github.com/bootstrap/scaffolding.html


* examples/info - a cloud information flask server developed (Hyungro)

* examples/openid - a flask server that demonstrates how to limit openid authentication to only a list of known open ids (Heshan)

* examples/bootstrap - two examples on how to use a more fancyful layout. one is in home.html, the other in fluid.html  
